use std::borrow::Cow;

use validator::Validate;

use super::response::{ResData, ResErr, ResResult};

pub fn validate_params(params: &impl Validate, _local: &str) -> ResResult<ResData<()>> {
    let validate_err = params.validate();
    match validate_err {
        Ok(_) => Result::Ok(ResData::none()),
        Err(err) => {
            let mut errors = vec![];
            for (_, err) in err.errors().iter() {
                match err {
                    validator::ValidationErrorsKind::Struct(err) => {
                        err.field_errors().iter().for_each(|(_field, errs)| {
                            errs.iter().for_each(|e| {
                                let msg = e.message.clone().unwrap_or_default();
                                let msg_str = msg.to_string();
                                errors.push(msg_str)
                            });
                        });
                    },
                    validator::ValidationErrorsKind::List(err) => {
                        for (_, err) in err.iter() {
                            err.field_errors().iter().for_each(|(_field, errs)| {
                                errs.iter().for_each(|e| {
                                    let msg = e.message.clone().unwrap_or_default();
                                    let msg_str = msg.to_string();
                                    errors.push(msg_str)
                                });
                            });
                        }
                    },
                    validator::ValidationErrorsKind::Field(err) => {
                        err.iter().for_each(|e| {
                            let msg = e.message.clone().unwrap_or_default();
                            let msg_str = msg.to_string();
                            errors.push(msg_str)
                        });
                    },
                };
            }
            Err(ResErr::params(errors.join(";")))
        },
    }
}